from django.db import models
from django.contrib.auth.models import User
from django.utils.translation import ugettext_lazy as _

# Create your models here.
class Character(models.Model):
    STATUS_CHOICES = (
        ('N', _('New')),
        ('A', _('Approved')),
    )
    created     = models.DateField(auto_now_add=1, verbose_name = _("Creation time"))
    modified    = models.DateField(auto_now=1, verbose_name = _("Modification time"))
    name        = models.CharField(max_length=255, verbose_name = _("Name"))
    status      = models.CharField(max_length=2, choices=STATUS_CHOICES, default='N', verbose_name = _("Status"))
    player      = models.ForeignKey(User, verbose_name = _("Player"))

    def __str__(self):
        return self.name

    class Meta:
        verbose_name = _("Character")
        verbose_name_plural = _("Characters")

class Influence(models.Model):
    STATUS_CHOICES = (
        ('N', _('New')),
        ('U', _('Under discussion')),
        ('P', _('Processing')),
        ('D', _('Done')),
    )
    created     = models.DateField(auto_now_add=1, verbose_name = _("Creation time"))
    modified    = models.DateField(auto_now=1, verbose_name = _("Modification time"))
    
    character   = models.ForeignKey(Character, verbose_name = _("Character"))
    contact     = models.CharField(max_length=255, verbose_name = _("Contact Name"))
    summary     = models.CharField(max_length=255, verbose_name = _("Summary"))
    description = models.TextField(verbose_name = _("Description"))
    status      = models.TextField(max_length=1, choices=STATUS_CHOICES, default='N', verbose_name = _("Status"))
    longterm    = models.BooleanField(default=False, verbose_name = _("Long term"))

    result      = models.TextField(blank=True,verbose_name = _("Result"))

    def __str__(self):
        return self.summary

    class Meta:
        verbose_name = _("Influence")
        verbose_name_plural = _("Influences")

# vim: set sts=4 sw=4 expandtab:
